# PXL

A collection of bits of Python code I've found useful for working with data,
plotting, etc., which aren't (to my knowledge) part of NumPy, Scipy, pandas, or
matplotlib.

## Installation

Run

    pip install pxl
